@@ -401,7 +401,9 @@ window_menu_plugin_screen_changed (GtkWidget *widget,
   /* get the wnck screen */
   screen = gtk_widget_get_screen (widget);
   panel_return_if_fail (GDK_IS_SCREEN (screen));
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
   wnck_screen = wnck_screen_get (gdk_screen_get_number (screen));
+G_GNUC_END_IGNORE_DEPRECATIONS
   panel_return_if_fail (WNCK_IS_SCREEN (wnck_screen));
 
   /* leave when we same wnck screen was picked */
@@ -851,9 +853,10 @@ window_menu_plugin_menu_workspace_item_active (GtkWidget     *mi,
 static GtkWidget *
 window_menu_plugin_menu_workspace_item_new (WnckWorkspace        *workspace,
                                             WindowMenuPlugin     *plugin,
-                                            PangoFontDescription *bold)
+                                            gboolean              bold)
 {
   const gchar *name;
+  gchar       *label_text = NULL;
   gchar       *utf8 = NULL, *name_num = NULL;
   GtkWidget   *mi, *label;
 
@@ -879,10 +882,18 @@ window_menu_plugin_menu_workspace_item_new (WnckWorkspace        *workspace,
   panel_return_val_if_fail (GTK_IS_LABEL (label), NULL);
   gtk_label_set_ellipsize (GTK_LABEL (label), plugin->ellipsize_mode);
   gtk_label_set_max_width_chars (GTK_LABEL (label), plugin->max_width_chars);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.5);
 
   /* modify the label font if needed */
-  if (bold != NULL)
-    gtk_widget_modify_font (label, bold);
+  if (bold)
+    label_text = g_strdup_printf ("<b>%s</b>", name);
+  else
+    label_text = g_strdup_printf ("<i>%s</i>", name);
+  if (label_text)
+  {
+    gtk_label_set_markup (GTK_LABEL (label), label_text);
+    g_free (label_text);
+  }
 
   g_free (utf8);
   g_free (name_num);
@@ -943,15 +954,10 @@ window_menu_plugin_menu_window_item_activate (GtkWidget      *mi,
       g_signal_connect (G_OBJECT (menu), "selection-done",
           G_CALLBACK (window_menu_plugin_menu_actions_selection_done),
           gtk_widget_get_parent (mi));
-#if GTK_CHECK_VERSION (3, 22, 0)
       gtk_menu_popup_at_widget (GTK_MENU (menu), mi,
-                                GDK_GRAVITY_SOUTH,
+                                GDK_GRAVITY_NORTH_EAST,
                                 GDK_GRAVITY_NORTH_WEST,
                                 (GdkEvent *) event);
-#else
-      gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL,
-                      NULL, event->button, event->time);
-#endif
 
       return TRUE;
     }
@@ -970,6 +976,7 @@ window_menu_plugin_menu_window_item_new (WnckWindow           *window,
                                          gint                  icon_h)
 {
   const gchar *name, *tooltip;
+  gchar       *label_text = NULL;
   gchar       *utf8 = NULL;
   gchar       *decorated = NULL;
   GtkWidget   *mi, *label, *image;
@@ -1009,14 +1016,19 @@ G_GNUC_END_IGNORE_DEPRECATIONS
   /* make the label pretty on long window names */
   label = gtk_bin_get_child (GTK_BIN (mi));
   panel_return_val_if_fail (GTK_IS_LABEL (label), NULL);
-  gtk_label_set_ellipsize (GTK_LABEL (label), plugin->ellipsize_mode);
-  gtk_label_set_max_width_chars (GTK_LABEL (label), plugin->max_width_chars);
-
   /* modify the label font if needed */
   if (wnck_window_is_active (window))
-    gtk_widget_modify_font (label, italic);
+    label_text = g_strdup_printf ("<b><i>%s</i></b>", name);
   else if (wnck_window_or_transient_needs_attention (window))
-    gtk_widget_modify_font (label, bold);
+    label_text = g_strdup_printf ("<b>%s</b>", name);
+  if (label_text)
+    {
+      gtk_label_set_markup (GTK_LABEL (label), label_text);
+      g_free (label_text);
+    }
+
+  gtk_label_set_ellipsize (GTK_LABEL (label), plugin->ellipsize_mode);
+  gtk_label_set_max_width_chars (GTK_LABEL (label), plugin->max_width_chars);
 
   if (plugin->minimized_icon_lucency > 0)
     {
@@ -1207,11 +1219,7 @@ window_menu_plugin_menu_new (WindowMenuPlugin *plugin)
         {
           /* create the workspace menu item */
           mi = window_menu_plugin_menu_workspace_item_new (workspace, plugin,
-              workspace == active_workspace ? bold : italic);
-          gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-          gtk_widget_show (mi);
-
-          mi = gtk_separator_menu_item_new ();
+              workspace == active_workspace);
           gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
           gtk_widget_show (mi);
 
@@ -1254,12 +1262,9 @@ window_menu_plugin_menu_new (WindowMenuPlugin *plugin)
             urgent_windows++;
         }
 
-      if (has_windows)
-        {
-          mi = gtk_separator_menu_item_new ();
-          gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-          gtk_widget_show (mi);
-        }
+      mi = gtk_separator_menu_item_new ();
+      gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
+      gtk_widget_show (mi);
     }
 
   /* destroy the last menu item if it's a separator */
@@ -1399,16 +1404,9 @@ window_menu_plugin_menu (GtkWidget        *button,
   g_signal_connect (G_OBJECT (menu), "deactivate",
       G_CALLBACK (window_menu_plugin_menu_selection_done), button);
 
-#if GTK_CHECK_VERSION (3, 22, 0)
   gtk_menu_popup_at_widget (GTK_MENU (menu), button,
                             xfce_panel_plugin_get_orientation (XFCE_PANEL_PLUGIN (plugin)) == GTK_ORIENTATION_VERTICAL
-                            ? GDK_GRAVITY_WEST : GDK_GRAVITY_NORTH,
-                            xfce_panel_plugin_get_orientation (XFCE_PANEL_PLUGIN (plugin)) == GTK_ORIENTATION_VERTICAL
-                            ? GDK_GRAVITY_EAST : GDK_GRAVITY_SOUTH,
+                            ? GDK_GRAVITY_NORTH_EAST : GDK_GRAVITY_SOUTH_WEST,
+                            GDK_GRAVITY_NORTH_WEST,
                             NULL);
-#else
-  gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-                  button != NULL ? xfce_panel_plugin_position_menu : NULL,
-                  plugin, 1, gtk_get_current_event_time ());
-#endif
 }
